Options

Don't forget to save settings after changing
Backend

Host |
| Auth token (if necessary) |

Notifications
Show 'Has contexts' popup (green)
Verbose errors (for debugging, may result in notification spam)
Behaviour
Highlight contexts (experimental, may result in slowdown on huge pages)
Blacklisted links and domains:
Source map
Style settings (CSS)
Sidebar style (DEPRECATED!)
If you had any settings here, please move them to the field above